@@ -2,23 +2,11 @@ package Devel::REPL::Plugin::CompletionDriver::LexEnv;
 use Devel::REPL::Plugin;
 use namespace::clean -except => [ 'meta' ];
 
-sub AFTER_PLUGIN {
-  my ($_REPL) = @_;
-
-  if (!$_REPL->can('lexical_environment')) {
-    warn "Devel::REPL::Plugin::CompletionDriver::LexEnv requires Devel::REPL::Plugin::LexEnv.";
-  }
-}
-
 around complete => sub {
   my $orig = shift;
   my ($self, $text, $document) = @_;
 
-  # recursively find the last element
-  my $last = $document;
-  while ($last->can('last_element') && defined($last->last_element)) {
-      $last = $last->last_element;
-  }
+  my $last = $self->last_ppi_element($document);
 
   return $orig->(@_)
     unless $last->isa('PPI::Token::Symbol');
@@ -31,8 +19,20 @@ around complete => sub {
          map  { $sigil eq '%' ? '%' . $_ : $_ }
          grep { /$re/ }
          map  { substr($_, 1) } # drop lexical's sigil
-         keys %{$self->lexical_environment->get_context('_')};
+         '$_REPL', keys %{$self->lexical_environment->get_context('_')};
 };
 
 1;
 
+__END__
+
+=head1 NAME
+
+Devel::REPL::Plugin::CompletionDriver::LexEnv - Complete variable names in the REPL's lexical environment
+
+=head1 AUTHOR
+
+Shawn M Moore, C<< <sartak at gmail dot com> >>
+
+=cut
+
