@@ -1,6 +1,6 @@
 package Devel::REPL::Plugin::Timing;
 
-use Moose::Role;
+use Devel::REPL::Plugin;
 use Time::HiRes 'time';
 use namespace::clean -except => [ 'meta' ];
 
@@ -24,3 +24,15 @@ around 'eval' => sub {
 
 1;
 
+__END__
+
+=head1 NAME
+
+Devel::REPL::Plugin::Timing - display execution times
+
+=head1 AUTHOR
+
+Shawn M Moore, C<< <sartak at gmail dot com> >>
+
+=cut
+
